import telegrambotmanager_andreconjo.config as config

bot = config.setup_bot()
keys = config.setup_keys_and_replys();

@bot.message_handler()
def reply_about_churras(message):
    tuple = next(filter(lambda key: message.text in key[0], keys), False)
    if tuple:
	    bot.reply_to(message, tuple[1])


def start():
    print('Iniciado com sucesso!')
    bot.infinity_polling()
    


def setup_config_file(file):
    import telegrambotmanager_andreconjo.config as config
    config.ini_config = file

def start_bot():
    import telegrambotmanager_andreconjo.bot as bot
    bot.start();


import configparser

parser = configparser.ConfigParser()
def prepare_keywords(list):
    return [word.strip() for word in list.split(',')]

ini_config = ''
def setup_bot():
    config_file = open(ini_config,  encoding='utf-8').read()
    parser.read_string(config_file)
    bot_token = parser[parser.default_section]['bot_token']
    import telebot
    return telebot.TeleBot(bot_token, parse_mode=None)

def setup_keys_and_replys():
    active_sections = prepare_keywords(parser[parser.default_section]['active_sections'])
    all_tuples = []
    for item in active_sections:
        all_tuples.append((prepare_keywords(parser[item]['keywords']), parser[item]['reply']))
    return all_tuples

